

# Copyright (C) 2016-2023 RhodeCode GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License, version 3
# (only), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This program is dual-licensed. If you wish to learn more about the
# RhodeCode Enterprise Edition, including its added features, Support services,
# and proprietary license terms, please see https://rhodecode.com/licenses/

import os
import configparser

from rhodecode.lib.config_utils import get_config
from pyramid.paster import bootstrap as pyramid_bootstrap, setup_logging  # pragma: no cover


def bootstrap(config_uri, options=None, env=None):
    from rhodecode.lib.utils2 import AttributeDict
    from rhodecode.lib.request import Request

    if env:
        os.environ.update(env)

    config = get_config(config_uri)
    base_url = 'http://rhodecode.local'
    try:
        base_url = config.get('app:main', 'app.base_url')
    except (configparser.NoSectionError, configparser.NoOptionError):
        pass

    request = Request.blank('/', base_url=base_url)
    # fake inject a running user for bootstrap request !
    request.user = AttributeDict({'username': 'bootstrap-user',
                                  'user_id': 1,
                                  'ip_addr': '127.0.0.1'})
    return pyramid_bootstrap(config_uri, request=request, options=options)

